@@ -1,5 +1,6 @@
 import datetime
 import time
+import re
 import pyspark.sql.functions as fn
 from pyspark.sql.types import *
 from pyspark.sql import Window, DataFrame, Row
@@ -11,6 +12,10 @@ class SparkCacheNotRegistException(Exception):
     def __init__(self):
         super().__init__()
 
+def filename_to_membername(filename):
+    member_name = "_file_content_"+filename.split("/")[-1].replace(".", "_")
+    member_name = f"_file_content_{re.sub('[^a-zA-Z0-9]', '_', filename)}"
+    return member_name
 
 class SparkCache(object):
     cache = None
@@ -22,19 +27,23 @@ class SparkCache(object):
     code = None
     debug = False
     spark = None
+    url = None
     dt = datetime.datetime.strftime(datetime.datetime.now()-datetime.timedelta(days=2), '%Y-%m-%d')
     def __init__(self):
         assert self.registed, "You must run SparkCache.regist([job], [hdfs_prefix]) first!!"
     
-    def set_conf_str(self, field, file_name):
-        name = f"conf_str_{field}"
+
+    def set_file_content(self, filename):
+        file_content = self.code(filename)
+        member_name = filename_to_membername(filename)
+        setattr(self, member_name, file_content)
     
-    def get_conf_str(self, field):
-        name = f"conf_str_{field}"
-        if not hasattr(self, name):
+    def get_file_content(self, filename):
+        member_name = filename_to_membername(filename)
+        if not hasattr(self, member_name):
             return None
         else:
-            return getattr(self, name)
+            return getattr(self, member_name)
 
     def enable_global_dump(cls): cls.dump = True
     def disable_global_dump(cls): cls.dump = False
@@ -42,21 +51,21 @@ class SparkCache(object):
     def enable_debug(self): self.debug = True
     def disable_debug(self): self.debug = False
 
+    def init_code(self, url):
+        self.code = Code(url=url)
+
     @classmethod
     def regist(cls, spark, job, hdfs_prefix, url=None, filenames=[]):
-	    cls.spark = spark
+        cls.spark = spark
         cls.job = job
         cls.hdfs_prefix = hdfs_prefix
         cls.registed = True
         cls.cache = SparkCache()
         cls.dep_map = dict()
         if url:
-            cls.code = Code(url=url)
-            cls.filenames = filenames
+            cls.cache.init_code(url)
             for filename in filenames:
-                file_content = cls.code(filename)
-                member_name = "file_content_"+filename.split("/")[-1].replace(".", "_")
-                setattr(cls, member_name, file_content)
+                cls.cache.set_file_content(filename)
             # globals()['cache'] = cls.cache
 
     def sample_if_debug(self, df, field, rate=0.01):
@@ -101,7 +110,10 @@ class SparkCache(object):
 
     def dumphdfs(self, field):
         df = self.get(field)
+        if df.rdd.isEmpty():
+            return False
         df.write.format("orc").mode("overwrite").save(self.hdfspath(field))
+        return True
     
     def loadhdfs(self, field):
         if self.has(field):
@@ -222,8 +234,7 @@ def spark_step(out, deps=[], dump=False, verbose=True, joinkeys=[], join_sample_
             cache.set(self.out, df_out)
 
             if cache.dump or self.dump:
-                cache.dumphdfs(self.out)
-                if self.verbose:
+                if cache.dumphdfs(self.out) and self.verbose:
                     print(f"dump hdfs path = {cache.hdfspath(self.out)}")
             if self.verbose:
                 count = df_out.count()
